/*
 * @Descripttion:
 * @version:
 * @Author: kBank
 * @Date: 2023-02-22 09:47:50
 */
import request from '@/utils/request'

// 公告列表
export function noticeList(data) {
  return request({
    url: '/system/manage/notice-config/list',
    method: 'post',
    data
  })
}
// 公告类型
export function noticeType(params) {
  return request({
    url: '/system/pub/enums/notice-type',
    method: 'get',
    params
  })
}

export function systemTypeAll(params) {
  return request({
    url: '/system/manage/system-type/all-list',
    method: 'get',
    params
  })
}
// 公告等级
export function noticeGrade(params) {
  return request({
    url: '/system/pub/enums/notice-grade',
    method: 'get',
    params
  })
}
// 获取公告
export function noticeGrade1(params) {
  return request({
    url: '/system/pub/enums/permission-type',
    method: 'get',
    params
  })
}

// 等级详情list
export function gradeRanglist(params) {
  return request({
    url: '/system/manage/grade/gradeRanglist',
    method: 'get',
    params
  })
}
// 奖衔详情list
export function awardsList(params) {
  return request({
    url: '/system/manage/awards/awardsList',
    method: 'get',
    params
  })
}
// 菜单list
export function menuList(params) {
  return request({
    url: '/system/pub/enums/menu-list',
    method: 'get',
    params
  })
}
// 后台公告配置
export function noticeAdmin(params) {
  return request({
    url: '/system/manage/notice-config/show-admin',
    method: 'get',
    params
  })
}
// 后台公告回显
export function noticeAdminData(params) {
  return request({
    url: '/system/manage/notice-config/admin-list',
    method: 'get',
    params
  })
}
// 公告配置保存
export function noticeSave(data) {
  return request({
    url: '/system/manage/notice-config/member-update',
    method: 'post',
    data
  })
}
// 公告配置保存后台
export function noticeAdminSave(data) {
  return request({
    url: '/system/manage/notice-config/admin-update',
    method: 'post',
    data
  })
}

// 公告网站类型
export function noticeWebsite(params) {
  return request({
    url: '/system/pub/enums/notice-website-type',
    method: 'get',
    params
  })
}
// 公告发布位置
export function noticeLocation(params) {
  return request({
    url: '/system/pub/enums/notice-location',
    method: 'get',
    params
  })
}
// 公告弹框
export function noticePopup(params) {
  return request({
    url: '/system/pub/enums/notice-popup-type',
    method: 'get',
    params
  })
}
// 公告状态
export function noticeState(params) {
  return request({
    url: '/system/pub/enums/notice-state',
    method: 'get',
    params
  })
}

// 公告列前台
export function noticeMemberList(data) {
  return request({
    url: '/system/manage/notice/member-list',
    method: 'post',
    data
  })
}
// 公告列后台
export function noticeAdminList(data) {
  return request({
    url: '/system/manage/notice/admin-list',
    method: 'post',
    data
  })
}
// 首页公告
export function indexNoticeAdminList(params) {
  return request({
    url: '/system/manage/notice/admin-right-list',
    method: 'get',
    params
  })
}
// 公告列详情
export function noticeDetails(params) {
  return request({
    url: '/system/manage/notice/show',
    method: 'get',
    params
  })
}
// 公告功能
export function noticeFuncType(params) {
  return request({
    url: '/system/pub/enums/notice-function-type',
    method: 'get',
    params
  })
}
// 角色列表
export function roleList(params) {
  return request({
    url: '/system/manage/role/list',
    method: 'get',
    params
  })
}
// 角色详情
export function roleDetails(params) {
  return request({
    url: '/system/manage/role/' + params,
    method: 'get'
    // params
  })
}
// 添加角色
export function addRole(data) {
  return request({
    url: '/system/manage/role',
    method: 'post',
    data
  })
}
// 修改角色
export function putRole(data) {
  return request({
    url: '/system/manage/role',
    method: 'put',
    data
  })
}
// 删除角色
export function delRole(params) {
  return request({
    url: '/system/manage/role/' + params,
    method: 'delete'
  })
}
// 部门列表
export function deptList(params) {
  return request({
    url: '/system/manage/dept/list',
    method: 'get',
    params
  })
}
// 部门详情
export function deptDetails(params) {
  return request({
    url: '/system/manage/dept/' + params,
    method: 'get'
    // params
  })
}
// 新增部门
export function addDept(data) {
  return request({
    url: '/system/manage/dept',
    method: 'post',
    data
  })
}
// 修改角色
export function putDept(data) {
  return request({
    url: '/system/manage/dept',
    method: 'put',
    data
  })
}
// 删除角色
export function delDept(params) {
  return request({
    url: '/system/manage/dept/' + params,
    method: 'delete'
  })
}
// 停用部门
export function stopDept(data) {
  return request({
    url: '/system/manage/dept/change-status',
    method: 'put',
    data
  })
}
// 管理员列表
export function getUserAdmin(params) {
  return request({
    url: '/system/manage/user/all',
    method: 'get',
    params
  })
}
// 停用管理员
export function stopAdmin(data) {
  return request({
    url: '/system/manage/user/change-status',
    method: 'put',
    data
  })
}
// 管理员列表
export function userList(params) {
  return request({
    url: '/system/manage/user/list',
    method: 'get',
    params
  })
}
// 全部角色列表
export function roleAllList(params) {
  return request({
    url: '/system/manage/role/all',
    method: 'get',
    params
  })
}
// 全部部门列表
export function deptAllList(params) {
  return request({
    url: '/system/manage/dept/all',
    method: 'get',
    params
  })
}
// 全部菜单列表
export function menuAllList(params) {
  return request({
    url: '/system/manage/menu/all',
    method: 'get',
    params
  })
}
// 全部菜单列表和列
export function menuAllListAll(params) {
  return request({
    url: '/system/manage/role-menu-column/all/' + params,
    method: 'get'
  })
}
// 保存列菜单
export function saveRoleMenu(data) {
  return request({
    url: '/system/manage/role-menu-column/save',
    method: 'post',
    data
  })
}
// 获取根据名称获取列菜单
export function getRoleMenu(params) {
  return request({
    url: '/system/manage/role-menu-column/get-column/' + params,
    method: 'get'
  })
}
// 管理员详情
export function userDetails(params) {
  return request({
    url: '/system/manage/user/' + params,
    method: 'get'
    // params
  })
}
// 新增管理员
export function addUser(data) {
  return request({
    url: '/system/manage/user',
    method: 'post',
    data
  })
}
// 修改管理员
export function putUser(data) {
  return request({
    url: '/system/manage/user',
    method: 'put',
    data
  })
}
// 删除管理员
export function delUser(params) {
  return request({
    url: '/system/manage/user/' + params,
    method: 'delete'
  })
}
// 菜单权限列表
export function userMenuList(params) {
  return request({
    url: '/system/manage/user-menu/list',
    method: 'get',
    params
  })
}
// 菜单配置详情
export function userMenuDetails(params) {
  return request({
    url: '/system/manage/user/' + params,
    method: 'get'
  })
}
// 保存菜单配置
export function userMenu(data) {
  return request({
    url: '/system/manage/user-menu',
    method: 'post',
    data
  })
}
// 菜单列表
export function getMenuList(params) {
  return request({
    url: '/system/manage/menu/list',
    method: 'get',
    params
  })
}
// 菜单详情
export function menuDetail(params) {
  return request({
    url: '/system/manage/menu/' + params,
    method: 'get'
  })
}
// 菜单权限详情
export function menuDetails(params) {
  return request({
    url: '/system/manage/user-menu/' + params,
    method: 'get'
  })
}
// 新增菜单权限
export function addMenu(data) {
  return request({
    url: '/system/manage/menu',
    method: 'post',
    data
  })
}
// 修改菜单权限
export function updateMenu(data) {
  return request({
    url: '/system/manage/menu',
    method: 'put',
    data
  })
}
// 删除菜单
export function delMenu(params) {
  return request({
    url: '/system/manage/menu/' + params,
    method: 'delete'
  })
}

// 公告修改
export function noticeUpdate(data) {
  return request({
    url: '/system/manage/notice/update',
    method: 'post',
    data
  })
}
// 公告新增前台
export function noticeSaveMember(data) {
  return request({
    url: '/system/manage/notice/save',
    method: 'post',
    data
  })
}
// 公告新增后台
export function noticeSaveAdmin(data) {
  return request({
    url: '/system/manage/notice/admin-save',
    method: 'post',
    data
  })
}

// 公告删除
export function noticeDelete(params) {
  return request({
    url: '/system/manage/notice/delete',
    method: 'get',
    params
  })
}

// 发布公告-等级列表
export function getGradeRanglist(params) {
  return request({
    url: '/system/manage/grade/gradeRanglist',
    method: 'get',
    params
  })
}

// 发布公告-查看签呈
export function showNoticePetition(data) {
  return request({
    url: '/system/manage/notice/show-notice-petition',
    method: 'post',
    data
  })
}

// 操作记录列表
export function operationLogList(params) {
  return request({
    url: '/system/manage/operation-log/list',
    method: 'get',
    params
  })
}

// 操作功能
export function methodType(params) {
  return request({
    url: '/system/manage/operation-log/method-type',
    method: 'get',
    params
  })
}
// 操作模块
export function moduleType(params) {
  return request({
    url: '/system/manage/operation-log/module-type',
    method: 'get',
    params
  })
}

// 站内信配置
export function getPlateformList(params) {
  return request({
    url: '/system/manage/platform/message/show-list',
    method: 'get',
    params
  })
}
// 站内信配置-删除
export function deletePlateform(params) {
  return request({
    url: '/system/manage/platform/message/delete',
    method: 'get',
    params
  })
}
// 站内信配置-修改
export function updatePlateform(data) {
  return request({
    url: '/system/manage/platform/message/update',
    method: 'post',
    data
  })
}
// 站内信配置-发布/添加
export function savePlateform(data) {
  return request({
    url: '/system/manage/platform/message/save',
    method: 'post',
    data
  })
}
// 站内信配置-获取单条详情
export function getMessageDetail(params) {
  return request({
    url: '/system/manage/platform/message/detail',
    method: 'get',
    params
  })
}
// 站内信配置-审批类型
export function getApproveStatus(params) {
  return request({
    url: '/system/pub/enums/approve-recharge-status',
    method: 'get',
    params
  })
}
// 站内信配置-业务类型
export function getNoticeBusinessType(params) {
  return request({
    url: '/system/pub/enums/notice-business-type',
    method: 'get',
    params
  })
}

// 公告上移
export function upMove(params) {
  return request({
    url: '/system/manage/notice/up-move',
    method: 'get',
    params
  })
}
// 公告下移
export function dowmMove(params) {
  return request({
    url: '/system/manage/notice/down-move',
    method: 'get',
    params
  })
}
// 公告置顶
export function topMove(params) {
  return request({
    url: '/system/manage/notice/top',
    method: 'get',
    params
  })
}
// 公告取消置顶
export function cancelMove(params) {
  return request({
    url: '/system/manage/notice/cancel-top',
    method: 'get',
    params
  })
}
// 业务操作明细
export function businessList(params) {
  return request({
    url: '/system/manage/business-log/list',
    method: 'get',
    params
  })
}

// 业务操作明细-删除
export function deleteBusinessList(data) {
  return request({
    url: '/system/manage/operation-log/del-syslog',
    method: 'post',
    data
  })
}
// 获取订单状态
export function getStatus() {
  return request({
    url: '/system/pub/enums/order-status',
    method: 'get'

  })
}
